types/auth_messages_macos
library
Classes
-
MacOSAuthMessages
-
Class wrapping all authentication messages needed on macOS.
Provides default values for all messages.
Properties
-
macOSCancelButton
→ String
-
Message shown on a button that the user can click to leave the current
dialog.
no setter
-
macOSGoToSettingsDescription
→ String
-
Message advising the user to go to the settings and configure Biometrics
for their device.
no setter
-
macOSLockOut
→ String
-
Message advising the user to re-enable biometrics on their device.
It shows in a dialog on macOS.
no setter